@@ -59,6 +59,8 @@ getJuliaEnv <- function() {
 #' the same Julia server and share a single session.
 #' This can be useful for saving start-up/precompilation time when starting
 #' additional processes or when sharing global variables between processes.
+#' A usage scenario for this is a web server where reloading Julia for each
+#' new session should be avoided.
 #' \emph{For the standard way of starting Julia, this function is not needed.
 #' It is also not needed if child processes should use separate Julia sessions.}
 #'
@@ -96,21 +98,49 @@ getJuliaEnv <- function() {
 #' @seealso \link{JULIACONNECTOR_SERVER}
 #'
 #' @examples
-#' if (juliaSetupOk()) {
+#' if (juliaSetupOk() && Sys.getenv("NOT_CRAN") == "true") {
+#'    library(JuliaConnectoR)
+#'    library(future)
 #'
+#'    # 1) Start a shared Julia TCP server in the main R session, which may use all CPU threads
 #'    Sys.setenv("JULIA_NUM_THREADS" = parallel::detectCores())
+#'    stopJulia() # stop current Julia connection before starting server
 #'    startJuliaServer()
 #'
-#'    library(future)
-#'    plan(multisession) # use background R processes on the same machine
+#'    # 2) Create R workers
+#'    cl <- parallelly::makeClusterPSOCK(workers = 2)
 #'
-#'    juliaEval("global x = 1")
+#'    # 3) Warm-up R workers, load Julia and execute first Julia function
+#'    # (In practice, you could, e.g., trigger Julia pre-compilation here.)
+#'    parallel::clusterEvalQ(cl, {
+#'       library(JuliaConnectoR)
+#'       JuliaConnectoR::juliaEval("1")  # open Julia TCP connection on each worker
+#'    })
 #'
-#'    # Child processes now use the same Julia session:
-#'    f1 <- future({juliaEval("x")})
+#'    ## 4) Re-Use those warmed workers for use via futures
+#'    plan(cluster, workers = cl)
+#'
+#'    ## 5) Create a global variable for demonstration purposes (and stay thread safe)
+#'    juliaEval("global const counter = Threads.Atomic{Int}(0)")
+#'
+#'    incrementCounter <- function() {
+#'       JuliaConnectoR::juliaEval("Threads.atomic_add!(counter, 1)")
+#'    }
+#'
+#'    ## 6) Execute futures via worker-pool
+#'    f1 <- future({incrementCounter()})
+#'    f2 <- future({incrementCounter()})
 #'    value(f1)
+#'    value(f2)
 #'
-#'    plan(sequential) # close background workers
+#'    # Reading the value should demonstrate that the
+#'    # global variable is shared across workers.
+#'    juliaEval("counter[]")
+#'
+#'    ## 7) Cleanup
+#'    plan(sequential)
+#'    parallel::stopCluster(cl)
+#'    stopJulia()
 #'
 #' }
 #' \dontshow{
@@ -181,17 +211,54 @@ runJuliaServer <- function(port = 11980, multiclient = TRUE) {
            stdout = startupOutputFile, stderr = startupOutputFile,
            env = getJuliaEnv())
 
+   readJuliaOutputSafely <- function() {
+      tryCatch({
+         return(paste(suppressWarnings(readLines(startupOutputFile)), collapse = "\n"))
+      }, error = function(e) {
+         return(paste("[Could not read Julia output log: file is locked by the process.",
+                      "This is expected on Windows if the Julia process has not stopped.]"))
+      })
+   }
+
    # get information about the real port from the temporary file
    sleepTime <- 0.2
    timeSlept <- 0
+
+   timeSinceLastOutput <- 0
+   lastFileSize <- 0
+
+   # timeout happens if there is no output from Julia in this duration
+   silenceLimit <- as.integer(Sys.getenv("JULIACONNECTOR_SILENCE_TIMEOUT", 60))
+
+   # timeout happens after this time elapsed since starting up Julia
+   maxTimeout <- as.integer(Sys.getenv("JULIACONNECTOR_MAX_TIMEOUT", 300))
+
    while (file.access(portfilename, mode = 4) < 0) {
       Sys.sleep(sleepTime)
       timeSlept <- timeSlept + sleepTime
-      if (timeSlept >= 50) {
-         cat(c("Julia startup:\n"))
-         try({cat(paste(readLines(startupOutputFile), collapse = "\n"),
-                  file = stdout())})
-         stop("Timeout while waiting for response from Julia server")
+      timeSinceLastOutput <- timeSinceLastOutput + sleepTime
+
+      # Check if output file has grown (Julia is alive and talking/precompiling)
+      finfo <- file.info(startupOutputFile)
+      currentSize <- finfo$size
+
+      if (!is.na(currentSize) && currentSize > lastFileSize) {
+         # Output detected: Reset the silence timer
+         timeSinceLastOutput <- 0
+         lastFileSize <- currentSize
+      }
+
+      # Check for timeouts
+      if (timeSinceLastOutput >= silenceLimit) {
+         cat(c("Julia startup (timed out due to lack of output):\n"))
+         cat(readJuliaOutputSafely(), "\n")
+         stop(paste("Timeout: No output from Julia server for", silenceLimit, "seconds."))
+      }
+
+      if (timeSlept >= maxTimeout) {
+         cat(c("Julia startup (timed out due to total duration):\n"))
+         cat(readJuliaOutputSafely(), "\n")
+         stop(paste("Timeout: Julia server failed to start within", maxTimeout, "seconds."))
       }
    }
 
@@ -230,23 +297,31 @@ juliaSetupOk <- function() {
       juliaCmd <- getJuliaExecutablePath()
    })
    if (is.null(juliaCmd)) {
-      message("Julia not found")
+      message("Julia setup check failed: Julia command not found")
       return(FALSE)
    }
 
    juliaVersion <- getJuliaVersionViaCmd(juliaCmd)
    if (is.null(juliaVersion)) {
-      message("Julia could not be started")
+      message("Julia setup check failed: Julia version could not be determined")
       return(FALSE)
    }
 
    juliaVersion <- as.integer(unlist(strsplit(juliaVersion, ".", fixed = TRUE)))
    if (juliaVersion[1] < 1) {
-      message("Julia version is less than 1.0")
+      message("Julia setup check failed: Julia version is less than 1.0")
       return(FALSE)
-   } else {
-      return(TRUE)
    }
+
+   # try to actually start the connection
+   setupOk <- tryCatch({
+      ensureJuliaConnection()
+      TRUE
+   }, error = function(e) {
+      message("Julia setup check failed: ", e$message)
+      return(FALSE)
+   })
+   return(setupOk)
 }
 
 
