@@ -1,7 +1,11 @@
 Sys.unsetenv("R_TESTS")
 
-
 test_that("Some smoke tests", {
+
+   juliaVersion <- juliaEval("string(VERSION)")
+   expect_true(startsWith(juliaVersion, "1"))
+   print(paste("Starting tests with Julia version", juliaVersion))
+
    expect_equal(juliaCall("prod", c(1,2,3)), 6)
    juliaEval("")
    juliaCall("string", list())
@@ -1362,6 +1366,7 @@ test_that("Data frame can be translated", {
 
    testEcho(data.frame())
 
+   skip_on_cran() # don't test IndexedTables on CRAN
    Pkg <- juliaImport("Pkg")
    if (juliaEval('VERSION < v"1.6"')) {
       subproject <- "1_0"
@@ -1388,6 +1393,7 @@ test_that("Data frame can be translated", {
 
 
 test_that("Attempt to translate Julia Table with incompatible types results in proper error", {
+   skip_on_cran() # don't test IndexedTables on CRAN
    juliaEval("import IndexedTables")
    x <- juliaEval('IndexedTables.table(["a", 1, 2], [1,2,3])')
    expect_error(as.data.frame(x), regexp = 'Column type "Any" cannot be translated')
@@ -1432,11 +1438,11 @@ test_that("Broadcasting via dot syntax works", {
 })
 
 
-test_that("Environemnt variables for Julia can be set", {
+test_that("Environment variables for Julia can be set", {
    # prepare
    os <- Sys.info()['sysname']
    oldJuliaEnv <- Sys.getenv("JULIACONNECTOR_JULIAENV")
-   JuliaConnectoR:::stopJulia()
+   stopJulia()
 
    # Test with one variable
    Sys.setenv(JULIACONNECTOR_JULIAENV = "TESTVARIABLE1=1")
@@ -1478,10 +1484,10 @@ test_that("Iris/Flux example from README works", {
    #skip_if(Sys.info()["login"] %in% c("lenz", "Stefan Lenz", "selectstern", "lenzstef"))
    cat("\nExecuting README examples...\n")
 
-   if (juliaEval('VERSION < v"1.9"')) {
+   if (juliaEval('VERSION < v"1.10"')) {
       skip("Skip Flux example because Julia version is too old")
    } else {
-      projectFolder <- "project_1_9"
+      projectFolder <- "project_1_10"
    }
 
    Pkg <- juliaImport("Pkg")
